Class: Reading::RegularRow
Overview
Parses a normal CSV row into an array of hashes of item data. Typically a normal row describes one item and so it’s parsed into an array containing a single hash, but it’s also possible for a row to describe multiple items.
Method Summary
Methods inherited from Row
Constructor Details
This class inherits a constructor from Reading::Row